// $Id: car.h,v 1.2 2017/04/25 21:12:23 leavens Exp leavens $
#ifndef CAR_H
#define CAR_H 1
#include <stdlib.h>
#include <stdio.h>
// maximum length of names for make and model of cars
#define MAX_NAME_LEN 40
// format for reading names with scanf
#define NAME_FORMAT "%40s"

typedef struct car_s {
    char *make;
    char *model;
    int year;
} car_t;

typedef car_t *car;

// requires: manuf and mod are allocated (and not-NULL)
//           null-terminated strings and yr >= 1900 and malloc
//           has enough space to allocate a new car_t struct
// ensures: result is not NULL and points to a newly allocated
//          car_t struct with its make field equal to manuf,
//          its model field equal to mod, and its year field equal to yr.
extern car make_car(char *manuf, char *mod, int yr);

// requires: the make_prompt, model_prompt, and year_prompt arguments are
//           all allocated (and not NULL) and null-terminated strings,
//           stdin and stdout are open
//           and malloc has enough space to allocate a new car_t struct
// effect: prompts with make_prompt on stdout, reads the car's make from stdin,
//         then prompts with model_prompt on stdout, and reads the car's model
//         from stdin, then prompts with year_prompt, and reads the car's year
//         (as 4 digits) from stdin. If the year read is not at least 1900,
//         then print a message (on stdout) of the form
//         "You entered NNNN, please enter a year after 1899"
//         where NNNN is the year the user entered, and
//         then reprompt with year_prompt (on stdout) and read the year again
//         from stdin, until the year read is at least 1900.
//         Then creates a new car_t struct
//         and returns a pointer to it (which is not NULL).
//         The fields of the result, the new car_t struct, are
//         initialized to the values read from stdin; that is the make field
//         is equal to the make read from stdin, the model field is equal to
//         the model read from stdin, and the year field is equal to the year
//         read from stdin. 
extern car read_car(const char *make_prompt, const char *model_prompt,
		    const char *year_prompt);

// requires: c is allocated and not NULL 
// ensures: result is the value of c's make field
extern const char *car_make(car c);

// requires: c is allocated and not NULL 
// ensures: result is the value of c's model field
extern const char *car_model(car c);

// requires: c is allocated and not NULL 
// ensures: result is the value of c's year field
extern const int car_year(car c);

// requires: c is allocated and not NULL and malloc has enough space to
//           hold the result
// ensures: result is a string of the form "YEAR MAKE MODEL", where YEAR is
//          the value of c's year field, MAKE is the value in c's make field
//          and MODEL is the value in c's model field.
//          Result is not NULL and is null-terminated.
extern char *car_to_string(car c);
#endif
