// $Id: complex.h,v 1.2 2017/04/25 20:57:02 leavens Exp $
#ifndef COMPLEX_H
#define COMPLEX_H 1
#include <stdlib.h>
#include <stdbool.h>
typedef struct complex_s {
    double real;
    double imaginary;
} complex_t;

typedef complex_t *complex;

// requires: neither a nor b is not-a-number
//           and malloc has enough space to succeed in allocating a complex_t struct.
// ensures: result is non-NULL and allocated with its real field equal to a and its
//          imaginary field equal to b.
extern complex make_complex(double a, double b);

// requires: c is allocated (and not NULL)
// ensures: result is the value of the real field of c
extern double complex_real_part(complex c);

// requires: c is allocated (and not NULL)
// ensures: result is the value of the imaginary field of c
extern double complex_imaginary_part(complex c);

// requires: both c and d are allocated (and not NULL)
//           and malloc has enough space to succeed in allocating a complex_t struct
// ensures: result is the sum of c and d, that is
//          result's real field is the sum of c and d's real fields,
//          and result's imaginary field is the sum of c and d's imaginary fields.
extern complex add_complex(complex c, complex d);

// requires: both c and d are allocated (and not NULL)
// ensures: result is true just when the real fields of c and d are equal
//          and the imaginary fields of c and d are also equal.
extern bool equal_complex(complex c, complex d);
#endif
